<!-- docs/_sidebar.md -->

- [Home](/)
- [Installation](installation.md)
- [Getting Started](getting-started.md)
- [Features](features.md)
- [Examples](examples.md)
- [Architecture](architecture.md)
- [Comparison](comparison.md)
- [API](api.md)
- [Community Resources](community-resources.md)
- [GraphQL Support](graphql-integration.md)
- [Future Roadmap](roadmap.md)
- [Plugins](plugins.md)
- [Hosting](hosting.md)
- [Templates](templates.md)
- [Sponsors](sponsors.md)
